humanlinks.Link (Personsl Link) — amici1

# `humanlinks.Link` (Personsl Link)

Link(id, type, parent, child)

Master tables : humanlinks.Links (Personal Links)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Parency type (type) : The type of link. Pointer to LinkTypes.

- Who is… (parent) : Pointer to the person who is „parent“.

- To whom… (child) : Pointer to the person who is „child“.

- Type (type_as_parent) : Displays LinkTypes.as_parent() for this link.

- Type (type_as_child) : Displays LinkTypes.as_child() for this link.

- Name (name_column) : See `lino_xl.lib.humanlinks.models.Link.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.humanlinks.models.Link.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.humanlinks.models.Link.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
type | Parency type | The type of link. Pointer to LinkTypes.
parent | Who is… | Pointer to the person who is „parent“.
child | To whom… | Pointer to the person who is „child“.
type_as_parent | Type | Displays LinkTypes.as_parent() for this link.
type_as_child | Type | Displays LinkTypes.as_child() for this link.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |